Examples
========

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to fit the parameters of a SALT2 model to photometric light curve data.">

.. only:: html

    .. figure:: /examples/images/thumb/sphx_glr_plot_lc_fit_thumb.png

        :ref:`sphx_glr_examples_plot_lc_fit.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /examples/plot_lc_fit

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="How to use your own minimizer or MCMC sampler for fitting light curves.">

.. only:: html

    .. figure:: /examples/images/thumb/sphx_glr_plot_custom_fitter_thumb.png

        :ref:`sphx_glr_examples_plot_custom_fitter.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /examples/plot_custom_fitter
.. raw:: html

    <div style='clear:both'></div>



.. container:: sphx-glr-footer


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: examples_python.zip </examples/examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: examples_jupyter.zip </examples/examples_jupyter.zip>`

.. rst-class:: sphx-glr-signature

    `Generated by Sphinx-Gallery <http://sphinx-gallery.readthedocs.io>`_
